@@ -1,125 +1,225 @@
-import time
-from typing import Optional, AsyncGenerator, Union, List
+# Standard library imports
+import asyncio
 import json
 import logging
-import asyncio
+import time
 import uuid
 from enum import Enum
-from dotenv import load_dotenv
-from pydantic import BaseModel
-import httpx
+from typing import AsyncGenerator, List, Optional, Union
 
+# Third-party imports
+import httpx
+from dotenv import load_dotenv
 from langfuse import observe
 from langfuse.openai import AsyncOpenAI
+from pydantic import BaseModel
+from tenacity import retry, stop_after_attempt, wait_exponential
 
-from ..schemas import Message,ToolCall
-from ..db import MessageDB
-from ..core import Session
-from ..utils.tool_decorator import function_tool
+# Local imports
+from ..components import MessageStorageBase, MessageStorageLocal
+from ..schemas import Message, ToolCall
 from ..utils.mcp_convertor import MCPTool
+from ..utils.tool_decorator import function_tool
 
 load_dotenv(override=True)
 
-# Initialize logging(only needs to be done once)
+# Configure logging
 logging.basicConfig(
     level=logging.INFO,
     format="%(asctime)s [%(levelname)s] %(name)s: %(message)s"
 )
 
+
+class AgentConfig:
+    """Configuration constants for Agent class."""
+    
+    DEFAULT_NAME = "default_agent"
+    DEFAULT_MODEL = "gpt-4.1-mini"
+    DEFAULT_USER_ID = "default_user"
+    DEFAULT_SESSION_ID = "default_session"
+    DEFAULT_HISTORY_COUNT = 16
+    DEFAULT_MAX_ITER = 10
+    DEFAULT_MAX_CONCURRENT_TOOLS = 10  # Maximum concurrent tool calls
+    MCP_CACHE_TTL = 300  # 5 minutes
+    HTTP_TIMEOUT = 600.0  # 10 minutes
+    TOOL_RESULT_PREVIEW_LENGTH = 20
+    ERROR_RESPONSE_PREVIEW_LENGTH = 200
+    
+    # Retry configuration
+    RETRY_ATTEMPTS = 3
+    RETRY_MIN_WAIT = 1
+    RETRY_MAX_WAIT = 60
+    
+    DEFAULT_SYSTEM_PROMPT = (
+        "**Context Information:**\n"
+        "- Current user_id: {user_id}\n"
+        "- Current date: {date}\n" 
+        "- Current timezone: {timezone}\n\n\n"
+    )
+
+
 class ReplyType(Enum):
+    """Types of replies the agent can generate."""
+    
     SIMPLE_REPLY = "simple_reply"
     STRUCTURED_REPLY = "structured_reply"
     TOOL_CALL = "tool_call"
     ERROR = "error"
 
+
 class Agent:
     """
     Base class for creating an AI agent that can interact with users, manage tools, and handle multi-step reasoning.
+    
+    This class provides a comprehensive framework for building AI agents with the following capabilities:
+    - Multi-turn conversation handling
+    - Tool integration and execution
+    - MCP (Model Context Protocol) server support
+    - Sub-agent delegation
+    - Structured output generation
+    - Streaming responses
     """
 
-    DEFAULT_NAME = "default_agent"
-    DEFAULT_MODEL = "gpt-4.1-mini"
-
-    DEFAULT_SYSTEM_PROMPT = (
-        "**Context Information:**\n"
-        "- Current user_id: {user_id}\n"
-        "- Current date: {date}\n" 
-        "- Current timezone: {timezone}\n\n"
-        "**Basic Capabilities:**\n"
-        "- Respond directly when you can answer a question without tools\n"
-        "- Use available tools when specialized functionality is needed\n"
-        "- Handle multi-step reasoning and break down complex problems\n"
-        "- Be concise yet informative in your responses\n"
-        "- When uncertain, ask clarifying questions\n"
-        "- Acknowledge when a request is beyond your capabilities\n\n\n"
-    )
-
-
     def __init__(
         self, 
         name: Optional[str] = None,
         system_prompt: Optional[str] = None,
-        description: Optional[str] = None, # simple description of the agent for tool conversion , what the Agent does
+        description: Optional[str] = None,
+        agent_id: Optional[str] = None,
         model: Optional[str] = None,
         client: Optional[AsyncOpenAI] = None,
-        tools: Optional[list] = None,
-        mcp_servers: Optional[Union[str, list]] = None,
-        sub_agents: Optional[List[Union[tuple[str, str, str], 'Agent']]] = None,  # (name, description, server_url) or Agent instances
-        output_type: type[BaseModel] = None
+        tools: Optional[List] = None,
+        mcp_servers: Optional[Union[str, List[str]]] = None,
+        sub_agents: Optional[List[Union[tuple[str, str, str], 'Agent']]] = None,
+        output_type: Optional[type[BaseModel]] = None,
+        message_storage: Optional[MessageStorageBase] = None
     ):
         """
         Initialize the Agent with optional parameters.
+        
         Args:
-            name (Optional[str]): The name of the agent.
-            system_prompt (Optional[str]): Custom system prompt to prepend to the default.
-            description (Optional[str]): Simple description of the agent for tool conversion.
-            model (Optional[str]): The OpenAI model to use, defaults to DEFAULT_MODEL.
-            client (Optional[AsyncOpenAI]): Custom OpenAI client instance, defaults to a new AsyncOpenAI instance.
-            tools (Optional[list]): List of tool functions to register with the agent.
-            mcp_servers (Optional[Union[str, list]]): MCP server URLs to fetch tools from.
-            sub_agents (Optional[List[Union[tuple[str, str, str], 'Agent']]]): List of sub-agents to convert to tools.
-            output_type (type[BaseModel]): Pydantic model for structured output, can be overridden in chat method.
-
-        Initializes the agent with a name, system prompt, description, model, and tools.
-        If no name is provided, it defaults to "default_agent". The system prompt is a combination of a default prompt and any custom prompt provided.
-        The agent can also register tools, fetch tools from MCP servers, and convert sub-agents into tools.
+            name: The name of the agent
+            system_prompt: Custom system prompt to prepend to the default
+            description: Simple description of the agent for tool conversion
+            agent_id: Unique identifier for the agent
+            model: The OpenAI model to use
+            client: Custom OpenAI client instance
+            tools: List of tool functions to register
+            mcp_servers: MCP server URLs to fetch tools from
+            sub_agents: List of sub-agents to convert to tools
+            output_type: Pydantic model for structured output
+            message_storage: MessageStorageBase instance for message storage
         """
-        self.name: str = name or self.DEFAULT_NAME
-        self.system_prompt: str = self.DEFAULT_SYSTEM_PROMPT + (system_prompt or "")
-        self.description: str = description
-        self.model: str = model or self.DEFAULT_MODEL
-        self.client: AsyncOpenAI = client or AsyncOpenAI()
+        # Basic configuration
+        self.agent_id = agent_id or str(uuid.uuid4())
+        self.name = name or AgentConfig.DEFAULT_NAME
+        self.description = description
+        self.model = model or AgentConfig.DEFAULT_MODEL
+        self.client = client or AsyncOpenAI()
+        self.output_type = output_type
+        
+        # Message storage setup
+        if message_storage is not None:
+            self.message_storage = message_storage
+        else:
+            self.message_storage = MessageStorageLocal()
+
+        self.message_storage.set_agent_id(self.name + "_" + self.agent_id)
+        
+        # System prompt setup
+        self.system_prompt = AgentConfig.DEFAULT_SYSTEM_PROMPT + (system_prompt or "")
+        
+        # Tool management
         self.tools: dict = {}
-        self._register_tools(tools or [])
-        self.mcp_servers: list = mcp_servers or []
         self.mcp_tools: dict = {}
         self.mcp_tools_last_updated: Optional[float] = None
-        self.mcp_cache_ttl: int = 300  # 5 minutes
-        self.agent_tools = self._convert_sub_agents_to_tools(sub_agents)
-        self._register_tools(self.agent_tools)
-        self.output_type: type[BaseModel] = output_type
+        self.mcp_cache_ttl = AgentConfig.MCP_CACHE_TTL
+        
+        # Tool specs cache
+        self._tool_specs_cache: Optional[list] = None
+        self._tools_last_updated: Optional[float] = None
+        
+        # Initialize components
         self.logger = logging.getLogger(self.__class__.__name__)
-        if self.agent_tools:
-            self.logger.info("Registered agent tools: %s", [tool.tool_spec['name'] for tool in self.agent_tools])
+        self.mcp_servers = self._normalize_mcp_servers(mcp_servers)
+        
+        # Register tools
+        self._register_tools(tools or [])
+        
+        # Convert and register sub-agents as tools
+        agent_tools = self._convert_sub_agents_to_tools(sub_agents)
+        if agent_tools:
+            self._register_tools(agent_tools)
+            self.logger.info("Registered agent tools: %s", 
+                           [tool.tool_spec['name'] for tool in agent_tools])
+
+    def _normalize_mcp_servers(self, mcp_servers: Optional[Union[str, List[str]]]) -> List[str]:
+        """Normalize MCP servers input to a list."""
+        if not mcp_servers:
+            return []
+        if isinstance(mcp_servers, str):
+            return [mcp_servers]
+        return list(mcp_servers)
+
+    @property
+    def cached_tool_specs(self):
+        """
+        Returns the cached tool specifications, rebuilding if necessary.
+        """
+        if self._should_rebuild_cache():
+            self._rebuild_tool_cache()
+        return self._tool_specs_cache
+
+    def _should_rebuild_cache(self) -> bool:
+        """
+        Determine if the tool specs cache should be rebuilt.
+        Returns:
+        - True if the cache is empty or tools have changed
+        - False if the cache is valid
+        """
+        # If the cache is empty, we need to rebuild
+        if self._tool_specs_cache is None:
+            return True
+
+        # If the MCP tools have been updated, we need to rebuild
+        if self.mcp_tools_last_updated and (
+            self._tools_last_updated is None or 
+            self.mcp_tools_last_updated > self._tools_last_updated
+        ):
+            return True
+        
+        return False
+
+    def _rebuild_tool_cache(self):
+        """
+        Rebuild the tool specs cache.
+        This method collects all tools from both local and MCP sources,
+        and updates the cache with their specifications.
+        """
+        all_tools = list(self.tools.values()) + list(self.mcp_tools.values())
+        self._tool_specs_cache = [fn.tool_spec for fn in all_tools] if all_tools else None
+        self._tools_last_updated = time.time()
 
     async def __call__(
-            self,
-            user_message: Message | str,
-            session: Session,
-            history_count: int = 16,
-            max_iter: int = 5,
-            image_source: Optional[str] = None,
-            output_type: type[BaseModel] = None,
-            stream=False
-    ) -> str | BaseModel | AsyncGenerator[str, None]:
-        """
-        Call the agent to generate a reply based on the user message and session.
-        """
+        self,
+        user_message: Union[Message, str],
+        user_id: str = AgentConfig.DEFAULT_USER_ID,
+        session_id: str = AgentConfig.DEFAULT_SESSION_ID,
+        history_count: int = AgentConfig.DEFAULT_HISTORY_COUNT,
+        max_iter: int = AgentConfig.DEFAULT_MAX_ITER,
+        max_concurrent_tools: int = AgentConfig.DEFAULT_MAX_CONCURRENT_TOOLS,
+        image_source: Optional[str] = None,
+        output_type: Optional[type[BaseModel]] = None,
+        stream: bool = False,
+    ) -> Union[str, BaseModel, AsyncGenerator[str, None]]:
+        """Call the agent to generate a reply based on the user message."""
         return await self.chat(
             user_message=user_message,
-            session=session,
+            user_id=user_id,
+            session_id=session_id,
             history_count=history_count,
             max_iter=max_iter,
+            max_concurrent_tools=max_concurrent_tools,
             image_source=image_source,
             output_type=output_type,
             stream=stream
@@ -128,30 +228,33 @@ class Agent:
     @observe()
     async def chat(
         self,
-        user_message: Message | str,
-        session: Session,
-        history_count: int = 16,
-        max_iter: int = 10,
+        user_message: Union[Message, str],
+        user_id: str = AgentConfig.DEFAULT_USER_ID,
+        session_id: str = AgentConfig.DEFAULT_SESSION_ID,
+        history_count: int = AgentConfig.DEFAULT_HISTORY_COUNT,
+        max_iter: int = AgentConfig.DEFAULT_MAX_ITER,
+        max_concurrent_tools: int = AgentConfig.DEFAULT_MAX_CONCURRENT_TOOLS,
         image_source: Optional[str] = None,
-        output_type: type[BaseModel] = None,
-        stream=False
-    ) -> str | BaseModel | AsyncGenerator[str, None]:
+        output_type: Optional[type[BaseModel]] = None,
+        stream: bool = False
+    ) -> Union[str, BaseModel, AsyncGenerator[str, None]]:
         """
-        Generate a reply from the agent given a user message and session.
+        Generate a reply from the agent given a user message.
 
         Args:
-            user_message (Message | str): The latest user message.
-            session (Session): The session object managing message history.
-            history_count (int, optional): Number of previous messages to include. Defaults to 20.
-            max_iter (int, optional): Maximum model call attempts. Defaults to 10.
-            image_source (Optional[str], optional): Source of the image, if any can be a URL or File path or base64 string.
-            output_type (type[BaseModel], optional): Pydantic model for structured output. Defaults to the Agent setting but can be overridden in chat().
-            stream (bool, optional): Whether to stream the response. Defaults to False.
+            user_message: The latest user message
+            user_id: User identifier for message storage
+            session_id: Session identifier for message storage
+            history_count: Number of previous messages to include
+            max_iter: Maximum model call attempts
+            max_concurrent_tools: Maximum number of concurrent tool calls
+            image_source: Source of the image, if any (URL, file path, or base64 string)
+            output_type: Pydantic model for structured output
+            stream: Whether to stream the response
 
         Returns:
-            str | BaseModel | AsyncGenerator[str, None]: The agent's reply or error message.
+            The agent's reply, structured output, or error message
         """
-
         if output_type is None:
             output_type = self.output_type
             
@@ -163,24 +266,23 @@ class Agent:
             await self._register_mcp_servers(self.mcp_servers)
 
             # Store the incoming user message in session history
-            await self._store_user_message(user_message, session, image_source)
+            await self._store_user_message(user_message, user_id, session_id, image_source)
 
             # Build input messages once outside the loop
-            input_messages = [msg.to_dict() for msg in await session.get_messages(history_count)]
+            input_messages = [msg.to_dict() for msg in await self.message_storage.get_messages(user_id, session_id, history_count)]
 
             for attempt in range(max_iter):
-
-                reply_type, response = await self._call_model(input_messages, session, output_type, stream)
+                reply_type, response = await self._call_model(input_messages, user_id, session_id, output_type, stream)
 
                 if reply_type == ReplyType.SIMPLE_REPLY:
                     if not stream:
-                        await self._store_model_reply(str(response), session)
+                        await self._store_model_reply(str(response), user_id, session_id)
                     return response
                 elif reply_type == ReplyType.STRUCTURED_REPLY:
-                    await self._store_model_reply(response.model_dump_json(), session)
+                    await self._store_model_reply(response.model_dump_json(), user_id, session_id)
                     return response
                 elif reply_type == ReplyType.TOOL_CALL:
-                    await self._handle_tool_calls(response, session, input_messages)
+                    await self._handle_tool_calls(response, user_id, session_id, input_messages, max_concurrent_tools)
                 else:
                     self.logger.error("Unknown reply type: %s", reply_type)
                     return "Sorry, I encountered an error while processing your request."
@@ -193,24 +295,39 @@ class Agent:
             self.logger.exception("Agent chat error: %s", e)
             return "Sorry, something went wrong."
 
-    def as_tool(self,name: str = None, description: str = None,message_db: Optional[MessageDB] = None):
+    def as_tool(
+        self, 
+        name: Optional[str] = None, 
+        description: Optional[str] = None
+    ):
         """
         Convert the agent into an OpenAI tool function.
         Args:
             name (str): The name of the tool function.
             description (str): A brief description of what the tool does.
-            message_db (Optional[MessageDB]): Optional message database for storing messages.
         Returns:
             function: An asynchronous function that can be used as an OpenAI tool.
         """
-        @function_tool(name=name or self.name, description=description or self.description)
-        async def tool_func(simple_input: str, shared_context: Optional[str] = None, image_source: Optional[str] = None):
-            return await self.chat(user_message=f"### Shared Context:\n{shared_context}\n\n### User Input:\n{simple_input}" if shared_context else simple_input,
+
+        @function_tool(
+            name=name or self.name,
+            description=description or self.description,
+            param_descriptions={
+                "input": "A clear, focused instruction or question for the agent, sufficient to complete the task independently, with any necessary resources included.",
+                "expected_output": "Specification of the desired output format, structure, or content type.",
+                "image_source": "Optional image for analysis. Can be a URL (http/https) or base64 encoded image string."
+            }
+        )
+        async def tool_func(input: str, expected_output: str,image_source: Optional[str] = None):
+            user_message = f"### User Input:\n{input}"
+            if expected_output:
+                user_message += f"\n\n### Expected Output:\n{expected_output}"
+            return await self.chat(user_message=user_message,
                                    image_source=image_source,
-                                   session=Session(user_id=f"agent_{self.name}_as_tool", 
-                                                   session_id=f"{uuid.uuid4()}",
-                                                    message_db=message_db
-                                                   ))
+                                   user_id=f"agent_{self.name}_as_tool", 
+                                   session_id=f"{uuid.uuid4()}"
+                                   )
+
         return tool_func
 
     def _convert_sub_agents_to_tools(self, sub_agents: Optional[List[Union[tuple[str, str, str], 'Agent']]]) -> Optional[list]:
@@ -247,8 +364,15 @@ class Agent:
                 raise TypeError(f"Tool function '{fn.tool_spec['name']}' must be async.")
             if fn.tool_spec['name'] not in self.tools:
                 self.tools[fn.tool_spec['name']] = fn
+        
+        # 注册新工具后使缓存失效
+        self._tool_specs_cache = None
 
     @observe()
+    @retry(
+        stop=stop_after_attempt(AgentConfig.RETRY_ATTEMPTS),
+        wait=wait_exponential(multiplier=1, min=AgentConfig.RETRY_MIN_WAIT, max=AgentConfig.RETRY_MAX_WAIT)
+    )
     async def _register_mcp_servers(self, mcp_servers: Optional[Union[str, list]]) -> None:
         """
         Register tools from MCP servers, updating the local cache if needed.
@@ -277,23 +401,28 @@ class Agent:
         
         self.mcp_tools_last_updated = now
 
-    async def _store_user_message(self, user_message: Message | str, session: Session, image_source: Optional[str]) -> None:
+    async def _store_user_message(self, user_message: Message | str, user_id: str, session_id: str, image_source: Optional[str]) -> None:
         if isinstance(user_message, str):
             user_message = Message.create(content=user_message, role="user", image_source=image_source)
-        await session.add_messages(user_message)
+        await self.message_storage.add_messages(user_id, session_id, user_message)
 
-    async def _store_model_reply(self, reply_text: str, session: Session) -> None:
+    async def _store_model_reply(self, reply_text: str, user_id: str, session_id: str) -> None:
         model_msg = Message.create(content=reply_text, role="assistant")
-        await session.add_messages(model_msg)
+        await self.message_storage.add_messages(user_id, session_id, model_msg)
 
     @observe()
-    async def _call_model(self, input_msgs: list, session: Session, 
+    @retry(
+        stop=stop_after_attempt(AgentConfig.RETRY_ATTEMPTS),
+        wait=wait_exponential(multiplier=1, min=AgentConfig.RETRY_MIN_WAIT, max=AgentConfig.RETRY_MAX_WAIT)
+    )
+    async def _call_model(self, input_msgs: list, user_id: str, session_id: str,
                           output_type: type[BaseModel] = None, stream: bool = False) -> tuple[ReplyType, object]:
         """
-        Call the AI model with the provided input messages and session.
+        Call the AI model with the provided input messages.
         Args:
             input_msgs (list): List of input messages to send to the model.
-            session (Session): The session object managing message history.
+            user_id (str): User identifier for message storage.
+            session_id (str): Session identifier for message storage.
             output_type (type[BaseModel], optional): Pydantic model for structured output.
             stream (bool, optional): Whether to stream the response. Defaults to False.
         Returns:
@@ -302,15 +431,14 @@ class Agent:
         system_msg = {
             "role": "system",
             "content": self.system_prompt.format(
-                user_id=session.user_id, 
+                user_id=user_id, 
                 date=time.strftime('%Y-%m-%d'), 
                 timezone=time.tzname[0]
             )
         }
 
-        # 预先构建工具规格列表，避免重复计算
-        all_tools = list(self.tools.values()) + list(self.mcp_tools.values())
-        tool_specs = [fn.tool_spec for fn in all_tools] if all_tools else None
+        # 使用智能缓存的工具规格
+        tool_specs = self.cached_tool_specs
         
         # 预处理消息
         messages = [system_msg] + self._sanitize_input_messages(input_msgs)
@@ -320,7 +448,7 @@ class Agent:
             if output_type is not None:
                 response = await self.client.responses.parse(
                     model=self.model,
-                    tools=tool_specs,
+                    tools=tool_specs if tool_specs else [],
                     input=messages,
                     text_format=output_type
                 )
@@ -361,7 +489,7 @@ class Agent:
                                 content = event.delta
                                 if content:
                                     yield content
-                        await self._store_model_reply(event.response.output[0].content[0].text, session)
+                        await self._store_model_reply(event.response.output[0].content[0].text, user_id, session_id)
                     return ReplyType.SIMPLE_REPLY, stream_generator()
                 elif event_type == "function_call":
                     async for event in response:
@@ -383,13 +511,15 @@ class Agent:
             return ReplyType.ERROR, f"Model call error: {str(e)}"
     
     @observe()
-    async def _handle_tool_calls(self, tool_calls: list, session: Session, input_messages: list) -> None:
+    async def _handle_tool_calls(self, tool_calls: list, user_id: str, session_id: str, input_messages: list, max_concurrent_tools: int = AgentConfig.DEFAULT_MAX_CONCURRENT_TOOLS) -> None:
         """
-        Handle tool calls by executing them concurrently.
+        Handle tool calls by executing them concurrently with concurrency limit.
         Args:
             tool_calls (list): List of tool call messages to process.
-            session (Session): The session object managing message history.
+            user_id (str): User identifier for message storage.
+            session_id (str): Session identifier for message storage.
             input_messages (list): List of input messages to update with tool call results.
+            max_concurrent_tools (int): Maximum number of concurrent tool calls.
         Returns:
             None: This method modifies input_messages in place and does not return a value.
         """
@@ -397,20 +527,36 @@ class Agent:
         if tool_calls is None or not tool_calls:
             return None
 
-        tasks = [self._act(tc, session) for tc in tool_calls if getattr(tc, "type", None) == "function_call"]
+        # Filter function calls only
+        function_calls = [tc for tc in tool_calls if getattr(tc, "type", None) == "function_call"]
+        
+        if not function_calls:
+            return None
+
+        # Create semaphore to limit concurrent tool calls
+        semaphore = asyncio.Semaphore(max_concurrent_tools)
+        
+        async def execute_with_semaphore(tool_call):
+            async with semaphore:
+                return await self._act(tool_call, user_id, session_id)
+
+        # Execute tool calls with concurrency limit
+        tasks = [execute_with_semaphore(tc) for tc in function_calls]
         results = await asyncio.gather(*tasks)
+        
         # Safely add all tool messages after concurrent execution
         for tool_messages in results:
             if tool_messages:
                 input_messages.extend([msg.to_dict() for msg in tool_messages])
         return None
 
-    async def _act(self, tool_call, session: Session) -> Optional[list]:
+    async def _act(self, tool_call, user_id: str, session_id: str) -> Optional[list]:
         """
         Execute a single tool call and return the messages generated by the tool.
         Args:
             tool_call: The tool call message to process.
-            session (Session): The session object managing message history.
+            user_id (str): User identifier for message storage.
+            session_id (str): Session identifier for message storage.
         Returns:
             Optional[list]: A list of messages generated by the tool call, or None if the tool is not found or an error occurs.
         """
@@ -441,16 +587,23 @@ class Agent:
                 )
             )
 
+            def _format_tool_result_preview(result: str) -> str:
+                """Format tool result for preview in content."""
+                result_str = str(result)
+                if len(result_str) <= AgentConfig.TOOL_RESULT_PREVIEW_LENGTH:
+                    return result_str
+                return result_str[:AgentConfig.TOOL_RESULT_PREVIEW_LENGTH] + '...'
+
             tool_res_msg = Message(
                 type="function_call_output",
                 role="tool",
-                content=f"Tool `{name}` result: {str(result) if len(str(result)) < 20 else str(result)[:20] + '...'}",
+                content=f"Tool `{name}` result: {_format_tool_result_preview(result)}",
                 tool_call=ToolCall(
                     call_id=getattr(tool_call, "call_id", "001"),
                     output=json.dumps(result, ensure_ascii=False) if isinstance(result, (dict, list)) else str(result)
                 )
             )
-            await session.add_messages([tool_call_msg, tool_res_msg])
+            await self.message_storage.add_messages(user_id, session_id, [tool_call_msg, tool_res_msg])
             
             # Return the messages instead of modifying input_messages directly
             return [tool_call_msg, tool_res_msg]
@@ -471,91 +624,85 @@ class Agent:
         return input_messages
     
 
-    def _convert_http_agent_to_tool(self, server: str, name: str = None, description: str = None):
+    def _convert_http_agent_to_tool(
+        self, 
+        server: str, 
+        name: Optional[str] = None, 
+        description: Optional[str] = None
+    ):
         """
         Convert an HTTP-based agent into an OpenAI tool function.
         Args:
-            server (str): The URL of the HTTP agent server.
+            server (str): The base URL of the HTTP agent server.
             name (str): The name of the tool function.
             description (str): A brief description of what the tool does.
         Returns:
             function: An asynchronous function that can be used as an OpenAI tool.
         """
-        @function_tool(name=name, description=description)
-        async def tool_func(simple_input: str, shared_context: Optional[str] = None, image_source: Optional[str] = None):
-            request_body = {
-                "user_id": f"http_tool_{uuid.uuid4().hex[:8]}",
+        
+        @function_tool(
+            name=name,
+            description=description,
+            param_descriptions={
+                "input": "A clear, focused instruction or question for the agent, sufficient to complete the task independently, with any necessary resources included.",
+                "expected_output": "Specification of the desired output format, structure, or content type.",
+                "image_source": "Optional image for analysis. Can be a URL (http/https) or base64 encoded image string."
+            }
+        )
+        async def tool_func(input: str, expected_output: str, image_source: Optional[str] = None):
+            # 构建消息和请求体
+            user_message = f"### User Input:\n{input}"
+            if expected_output:
+                user_message += f"\n\n### Expected Output:\n{expected_output}"
+            
+            payload = {
+                "user_id": f"http_agent_tool_{name or 'default'}_{uuid.uuid4().hex[:8]}",
                 "session_id": f"session_{uuid.uuid4().hex[:8]}",
-                "user_message": f"### Shared Context:\n{shared_context}\n\n### User Input:\n{simple_input}" if shared_context else simple_input,
-                "stream": False  # 工具调用不使用流式响应
+                "user_message": user_message,
+                "stream": False
             }
             
             if image_source:
-                request_body["image_source"] = image_source
+                payload["image_source"] = image_source
             
-            chat_url = f"{server}/chat"
+            # 带重试的HTTP请求函数
+            @retry(
+                stop=stop_after_attempt(AgentConfig.RETRY_ATTEMPTS),
+                wait=wait_exponential(multiplier=1, min=AgentConfig.RETRY_MIN_WAIT, max=AgentConfig.RETRY_MAX_WAIT)
+            )
+            async def make_http_request():
+                async with httpx.AsyncClient(timeout=AgentConfig.HTTP_TIMEOUT) as client:
+                    return await client.post(f"{server}/chat", json=payload)
             
-            self.logger.info(f"Calling HTTP Agent at: {chat_url}")
-            self.logger.debug(f"Request body: {request_body}")
-
+            # 发送请求并处理响应
             try:
-                async with httpx.AsyncClient(timeout=60.0) as client:  # 增加超时时间
-                    response = await client.post(chat_url, json=request_body)
-                    
-                    self.logger.debug(f"HTTP response status: {response.status_code}")
-                    
-                    if response.status_code == 200:
-                        try:
-                            response_data = response.json()
-                            reply = response_data.get("reply", "")
-                            
-                            if reply:
-                                self.logger.info(f"HTTP Agent '{name}' responded successfully")
-                                return reply
-                            else:
-                                error_msg = "Empty reply from HTTP Agent"
-                                self.logger.warning(error_msg)
-                                return error_msg
-                                
-                        except json.JSONDecodeError as e:
-                            error_msg = f"Invalid JSON response from HTTP Agent: {str(e)}"
-                            self.logger.error(f"{error_msg}. Response text: {response.text[:200]}...")
-                            return error_msg
-                            
-                    elif response.status_code == 500:
-                        try:
-                            error_data = response.json()
-                            error_detail = error_data.get("detail", "Internal server error")
-                            error_msg = f"HTTP Agent internal error: {error_detail}"
-                        except:
-                            error_msg = f"HTTP Agent internal error: {response.text[:200]}"
-                        
-                        self.logger.error(error_msg)
-                        return error_msg
-                        
-                    else:
-                        error_msg = f"HTTP Agent error {response.status_code}: {response.text[:200]}"
-                        self.logger.error(error_msg)
-                        return error_msg
-                        
-            except httpx.ConnectError as e:
-                error_msg = f"Cannot connect to HTTP Agent at {chat_url}: {str(e)}"
-                self.logger.error(error_msg)
-                return error_msg
+                response = await make_http_request()
                 
-            except httpx.TimeoutException as e:
-                error_msg = f"HTTP Agent request timeout: {str(e)}"
-                self.logger.error(error_msg)
-                return error_msg
+                # 成功响应处理
+                if response.status_code == 200:
+                    data = response.json()
+                    reply = data.get("reply", "")
+                    if reply:
+                        return reply
+                    return "Empty reply from HTTP Agent"
                 
-            except httpx.RequestError as e:
-                error_msg = f"HTTP Agent request error: {str(e)}"
-                self.logger.error(error_msg)
-                return error_msg
+                # 错误响应处理
+                if response.status_code == 500:
+                    try:
+                        error_detail = response.json().get("detail", "Internal server error")
+                        return f"HTTP Agent internal error: {error_detail}"
+                    except:
+                        return f"HTTP Agent internal error: {response.text[:AgentConfig.ERROR_RESPONSE_PREVIEW_LENGTH]}"
                 
+                return f"HTTP Agent error {response.status_code}: {response.text[:AgentConfig.ERROR_RESPONSE_PREVIEW_LENGTH]}"
+                
+            except (httpx.ConnectError, httpx.TimeoutException, httpx.RequestError) as e:
+                error_type = type(e).__name__.replace('Exception', '').replace('Error', '')
+                return f"HTTP Agent {error_type.lower()}: {str(e)}"
+            except json.JSONDecodeError as e:
+                return f"Invalid JSON response: {str(e)}"
             except Exception as e:
-                error_msg = f"Unexpected error calling HTTP Agent: {str(e)}"
-                self.logger.exception(error_msg)
-                return error_msg
-        
+                self.logger.exception(f"HTTP Agent call failed: {e}")
+                return f"Unexpected error: {str(e)}"
+
         return tool_func
\ No newline at end of file
